@@ -1,6 +1,6 @@
 (**************************************************************************)
 (*  Mana : A kana(romaji)-kanji conversion engine using ChaSen algorithm.    *)
-(*  Copyright (C) 2003, 2004, 2005  Yamagata Yoriyuki                     *)
+(*  Copyright (C) 2003, 2004  Yamagata Yoriyuki                           *)
 (*                                                                        *)
 (*  This program is free software; you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU General Public License as published by  *)
@@ -12,7 +12,7 @@
 (*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *)
 (*  General Public License for more details.                              *)
 (**************************************************************************)
-
+ 
 let connect_mrph ~state ~mrph =
   let new_state, con_cost = 
     Chasen.connect_cost state mrph in
@@ -128,6 +128,11 @@ let parse string ~state ~pos ~len =
      in_vertex_map = IMap.empty} in
   let node_set = Array.init (pos + len + 1) Hashtbl.create in
   Hashtbl.add node_set.(pos) state init_node;
+  let no_conversion_list = 
+    Chasen.undefwords (EucString.sub string pos len) in
+  List.iter (fun mrph ->
+    add_vertex ~pos ~to_pos:(pos + len) ~state mrph node_set)
+    no_conversion_list;
   for p = pos to pos + len - 1 do
     let mrph_list = list_next_mrph string ~pos:p ~len:(len + pos - p) in
     Hashtbl.iter (fun state _ ->
